@@ -85,6 +85,11 @@ class ShowChanged(ApplicationEvent):
     show: str
 
 
+@dataclass
+class RegisterActions(ApplicationEvent):
+    name: str = field(init=False, default='register-actions')
+
+
 @dataclass
 class AccountConnected(ApplicationEvent):
     name: str = field(init=False, default='account-connected')
@@ -298,6 +303,18 @@ class AccountDisabled(ApplicationEvent):
     account: str
 
 
+@dataclass
+class AccountCreated(ApplicationEvent):
+    name: str = field(init=False, default='account-created')
+    account: str
+
+
+@dataclass
+class AccountRemoved(ApplicationEvent):
+    name: str = field(init=False, default='account-removed')
+    account: str
+
+
 @dataclass
 class FeatureDiscovered(ApplicationEvent):
     name: str = field(init=False, default='feature-discovered')
@@ -377,6 +394,7 @@ class GatewayPromptReceived(ApplicationEvent):
 @dataclass
 class ServerDiscoReceived(ApplicationEvent):
     name: str = field(init=False, default='server-disco-received')
+    account: str
 
 
 @dataclass
@@ -851,7 +869,8 @@ class EncryptionInfo(ApplicationEvent):
     name: str = field(init=False, default='encryption-check')
     account: str
     jid: JID
-    message: EncryptionInfoMsg
+    type: EncryptionInfoMsg
+    message: str
 
 
 @dataclass
