@@ -388,17 +388,28 @@ class Message(BaseModule):
 
         if message.reaction_data is not None:
             reactions_id, reactions = message.reaction_data
-            reaction = mod.Reaction(
-                account_=self._account,
-                remote_jid_=remote_jid,
-                occupant_=occupant,
-                id=reactions_id,
-                direction=direction,
-                emojis=';'.join(reactions),
-                timestamp=message.timestamp,
-            )
+            if not reactions:
+                app.storage.archive.delete_reaction(
+                    account=self._account,
+                    jid=remote_jid,
+                    occupant_id=occupant.id if occupant is not None else None,
+                    reaction_id=reactions_id,
+                    direction=direction,
+                )
+                self._log.info('Delete own reactions for: %s', reactions_id)
 
-            app.storage.archive.upsert_row2(reaction)
+            else:
+                reaction = mod.Reaction(
+                    account_=self._account,
+                    remote_jid_=remote_jid,
+                    occupant_=occupant,
+                    id=reactions_id,
+                    direction=direction,
+                    emojis=';'.join(reactions),
+                    timestamp=message.timestamp,
+                )
+
+                app.storage.archive.upsert_row2(reaction)
 
             app.ged.raise_event(
                 ReactionUpdated(
@@ -437,6 +448,10 @@ class Message(BaseModule):
             self._account, remote_jid, message.timestamp, message.sec_label)
         reply = get_reply(message.reply_data)
 
+        thread_id = None
+        if message.reply_data is not None:
+            thread_id = message.reply_data.thread_id
+
         oob_data: list[mod.OOB] = []
         if message.oob_url is not None:
             oob_data.append(mod.OOB(url=message.oob_url, description=None))
@@ -453,6 +468,7 @@ class Message(BaseModule):
             id=message.message_id,
             stanza_id=None,
             user_delay_ts=None,
+            thread_id_=thread_id,
             correction_id=message.correct_id,
             encryption_=encryption_data,
             oob=oob_data,
@@ -493,6 +509,8 @@ def build_message_stanza(message: OutgoingMessage, own_jid: JID) -> nbxmpp.Messa
     stanza.setID(message.message_id)
     stanza.setOriginID(message.message_id)
 
+    thread_id = None
+
     # Mark Message as MUC PM
     if message.is_pm:
         stanza.setTag('x', namespace=Namespace.MUC_USER)
@@ -509,6 +527,7 @@ def build_message_stanza(message: OutgoingMessage, own_jid: JID) -> nbxmpp.Messa
 
     # XEP-0461
     if message.reply_data is not None:
+        thread_id = message.reply_data.thread_id
         stanza.setReply(str(message.reply_data.to),
                         message.reply_data.id,
                         message.reply_data.fallback_start,
@@ -550,4 +569,9 @@ def build_message_stanza(message: OutgoingMessage, own_jid: JID) -> nbxmpp.Messa
     if message.mds_id is not None:
         stanza.setMdsAssist(message.mds_id, own_jid.new_as_bare())
 
+    # Thread
+    # Currently only supported for replies
+    if thread_id is not None:
+        stanza.setThread(thread_id)
+
     return stanza
