@@ -34,6 +34,7 @@ from datetime import datetime
 from datetime import timedelta
 from datetime import UTC
 
+from gi.repository import Adw
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
@@ -52,15 +53,16 @@ from gajim.common.const import GAJIM_FAQ_URI
 from gajim.common.const import GAJIM_PRIVACY_POLICY_URI
 from gajim.common.const import GAJIM_SUPPORT_JID
 from gajim.common.const import GAJIM_WIKI_URI
+from gajim.common.helpers import dump_json
 from gajim.common.helpers import load_json
 from gajim.common.i18n import _
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import ResourceContact
 from gajim.common.util.uri import open_uri
 
-from gajim.gtk import menus
 from gajim.gtk import structs
-from gajim.gtk.about import AboutDialog
+from gajim.gtk.alert import ConfirmationAlertDialog
+from gajim.gtk.alert import InformationAlertDialog
 from gajim.gtk.avatar import AvatarStorage
 from gajim.gtk.const import ACCOUNT_ACTIONS
 from gajim.gtk.const import ALWAYS_ACCOUNT_ACTIONS
@@ -68,11 +70,9 @@ from gajim.gtk.const import APP_ACTIONS
 from gajim.gtk.const import FEATURE_ACCOUNT_ACTIONS
 from gajim.gtk.const import MuteState
 from gajim.gtk.const import ONLINE_ACCOUNT_ACTIONS
-from gajim.gtk.dialogs import ConfirmationDialog
-from gajim.gtk.dialogs import DialogButton
-from gajim.gtk.dialogs import ShortcutsWindow
-from gajim.gtk.menus import get_main_menu
+from gajim.gtk.const import SHORTCUTS
 from gajim.gtk.util.icons import get_icon_theme
+from gajim.gtk.util.misc import add_alternative_accelerator
 from gajim.gtk.util.window import get_app_window
 from gajim.gtk.util.window import get_app_windows
 from gajim.gtk.util.window import open_window
@@ -80,7 +80,7 @@ from gajim.gtk.util.window import open_window
 ActionListT = list[tuple[str, Callable[[Gio.SimpleAction, GLib.Variant], Any]]]
 
 
-class GajimApplication(Gtk.Application, CoreApplication):
+class GajimApplication(Adw.Application, CoreApplication):
     """Main class handling activation and command line."""
 
     def __init__(self):
@@ -89,7 +89,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
             Gio.ApplicationFlags.HANDLES_COMMAND_LINE
             | Gio.ApplicationFlags.CAN_OVERRIDE_APP_ID
         )
-        Gtk.Application.__init__(
+        Adw.Application.__init__(
             self, application_id=app.get_default_app_id(), flags=flags
         )
 
@@ -140,6 +140,15 @@ class GajimApplication(Gtk.Application, CoreApplication):
             "NAME",
         )
 
+        self.add_main_option(
+            "user-profile",
+            ord("u"),
+            GLib.OptionFlags.NONE,
+            GLib.OptionArg.STRING,
+            _("Use a profile to run multiple Gajim instances"),
+            "NAME",
+        )
+
         self.add_main_option(
             "config-path",
             ord("c"),
@@ -223,16 +232,18 @@ class GajimApplication(Gtk.Application, CoreApplication):
         icon_theme = get_icon_theme()
         icon_theme.add_search_path(str(configpaths.get("ICONS")))
 
-        self.set_menubar(get_main_menu())
+        self.avatar_storage = AvatarStorage()
+
+        app.load_css_config()
+
+        from gajim.gtk.main import MainWindow
+
+        main_window = MainWindow()
 
         from gajim.gtk import notification
 
         notification.init()
 
-        self.avatar_storage = AvatarStorage()
-
-        app.load_css_config()
-
         idle.Monitor.set_interval(
             app.settings.get("autoawaytime") * 60, app.settings.get("autoxatime") * 60
         )
@@ -247,14 +258,26 @@ class GajimApplication(Gtk.Application, CoreApplication):
             self.add_account_actions(account)
 
         self._load_shortcuts()
-        menus.build_accounts_menu()
         self.update_app_actions_state()
 
         self.register_event("feature-discovered", ged.CORE, self._on_feature_discovered)
 
-        from gajim.gtk.main import MainWindow
+        main_window.init()
 
-        MainWindow()
+        if self._deprecated_options_used:
+            migration_url = (
+                "https://dev.gajim.org/gajim/gajim/-/wikis/Profile-Migration"
+            )
+            InformationAlertDialog(
+                "Deprecation Warning",
+                (
+                    "The options <b>--profile</b> and <b>--separate</b> are deprecated "
+                    "and will be removed in a future version of Gajim. Visit our "
+                    f"<a href='{migration_url}'>Wiki</a> "
+                    "to find the instructions on how to migrate."
+                ),
+                body_use_markup=True,
+            )
 
         GLib.timeout_add(100, self._auto_connect)
 
@@ -303,17 +326,36 @@ class GajimApplication(Gtk.Application, CoreApplication):
             print(gajim.__version__)
             return 0
 
+        application_name = "Gajim"
+
+        # --profile is deprecated with Gajim 2.3.0
         profile = options.lookup_value("profile")
-        if profile is None:
-            GLib.set_application_name("Gajim")
-        else:
-            # Incorporate profile name into application id
-            # to have a single app instance for each profile.
-            profile = profile.get_string()
-            GLib.set_application_name(f"Gajim ({profile})")
-            app_id = f"{self.get_application_id()}.{profile}"
+        user_profile = options.lookup_value("user-profile")
+        if user_profile is not None:
+            if options.contains("separate"):
+                print("--separate cannot be used with --user-profile")
+                return 0
+
+            if options.contains("profile"):
+                print("--profile cannot be used with --user-profile")
+                return 0
+
+            configpaths.set_user_profile(user_profile.get_string())
+
+        elif profile is not None:
+            user_profile = profile
+            configpaths.set_profile(user_profile.get_string())
+
+        if user_profile is not None:
+            # Incorporate user_profile name into application id
+            # to have a single app instance for each user_profile.
+            user_profile_str = user_profile.get_string()
+            application_name = f"Gajim ({user_profile_str})"
+            app_id = f"{self.get_application_id()}.{user_profile_str}"
             self.set_application_id(app_id)
-            configpaths.set_profile(profile)
+            configpaths.set_user_profile(user_profile_str)
+
+        GLib.set_application_name(application_name)
 
         self.register()
         if self.get_is_remote():
@@ -323,6 +365,10 @@ class GajimApplication(Gtk.Application, CoreApplication):
             )
             return -1
 
+        self._deprecated_options_used = options.contains("profile") or options.contains(
+            "separate"
+        )
+
         options.insert_value("is-first-startup", GLib.Variant("b", True))
         self._core_command_line(options)
         self._startup()
@@ -397,14 +443,9 @@ class GajimApplication(Gtk.Application, CoreApplication):
             ("add-contact", self._on_add_contact_account_action),
             ("services", self._on_services_action),
             ("profile", self._on_profile_action),
-            ("server-info", self._on_server_info_action),
-            ("archive", self._on_archive_action),
             ("pep-config", self._on_pep_config_action),
-            ("sync-history", self._on_sync_history_action),
-            ("blocking", self._on_blocking_action),
             ("open-event", self._on_open_event_action),
             ("mark-as-read", self._on_mark_as_read_action),
-            ("manage-roster", self._on_manage_roster_action),
             ("block-contact", self._on_block_contact),
             ("remove-contact", self._on_remove_contact),
             ("execute-command", self._on_execute_command),
@@ -440,11 +481,8 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     def update_feature_actions_state(self, account: str) -> None:
         client = app.get_client(account)
-        mam_available = client.get_module("MAM").available
         blocking_available = client.get_module("Blocking").supported
 
-        self.set_action_state(f"{account}-archive", mam_available)
-        self.set_action_state(f"{account}-blocking", blocking_available)
         self.set_action_state(f"{account}-block-contact", blocking_available)
 
     def update_app_actions_state(self) -> None:
@@ -454,21 +492,33 @@ class GajimApplication(Gtk.Application, CoreApplication):
         enabled_accounts = bool(app.settings.get_active_accounts())
         self.set_action_state("start-chat", enabled_accounts)
 
-    def _load_shortcuts(self) -> None:
-        default_path = configpaths.get("DATA") / "other" / "shortcuts.json"
-        shortcuts = load_json(default_path)
-        assert shortcuts is not None
-
+    @staticmethod
+    def get_user_shortcuts() -> dict[str, list[str]]:
         user_path = configpaths.get("MY_SHORTCUTS")
-        user_shortcuts = {}
+        user_shortcuts: dict[str, list[str]] = {}
         if user_path.exists():
             app.log("app").info("Load user shortcuts")
             user_shortcuts = load_json(user_path, default={})
 
+        return user_shortcuts
+
+    def set_user_shortcuts(self, user_shortcuts: dict[str, list[str]]) -> None:
+        user_path = configpaths.get("MY_SHORTCUTS")
+        dump_json(user_path, user_shortcuts)
+        self._load_shortcuts()
+
+    def _load_shortcuts(self) -> None:
+        shortcuts = {
+            action_name: shortcut_data.accelerators
+            for action_name, shortcut_data in SHORTCUTS.items()
+        }
+        user_shortcuts = self.get_user_shortcuts()
         shortcuts.update(user_shortcuts)
 
-        for action, accels in shortcuts.items():
-            self.set_accels_for_action(action, accels)
+        for action, accelerators in shortcuts.items():
+            self.set_accels_for_action(
+                action, add_alternative_accelerator(accelerators)
+            )
 
     def _on_feature_discovered(self, event: events.FeatureDiscovered) -> None:
         self.update_feature_actions_state(event.account)
@@ -492,17 +542,9 @@ class GajimApplication(Gtk.Application, CoreApplication):
         # Action must be added before account window is updated
         self.add_account_actions(account)
 
-        window = get_app_window("AccountsWindow")
-        if window is not None:
-            window.add_account(account)
-
     def enable_account(self, account: str) -> None:
         CoreApplication.enable_account(self, account)
-        menus.build_accounts_menu()
         self.update_app_actions_state()
-        window = get_app_window("AccountsWindow")
-        if window is not None:
-            window.enable_account(account, True)
 
     def disable_account(self, account: str) -> None:
         for win in get_app_windows(account):
@@ -514,7 +556,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         CoreApplication.disable_account(self, account)
 
-        menus.build_accounts_menu()
         self.update_app_actions_state()
 
     def remove_account(self, account: str) -> None:
@@ -522,10 +563,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         self.remove_account_actions(account)
 
-        window = get_app_window("AccountsWindow")
-        if window is not None:
-            window.remove_account(account)
-
     def _on_db_migration(self, _event: events.DBMigration) -> None:
         open_window("DBMigration")
 
@@ -552,15 +589,15 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _on_plugins_action(
         _action: Gio.SimpleAction, _param: GLib.Variant | None
     ) -> None:
-        open_window("PluginsWindow")
+        open_window("Preferences").show_page("plugins")
 
     @staticmethod
     def _on_accounts_action(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        window = open_window("AccountsWindow")
+        window = open_window("Preferences")
 
         account = param.get_string()
         if account:
-            window.select_account(account)
+            window.show_page(account)
 
     @staticmethod
     def _on_quit_action(_action: Gio.SimpleAction, _param: GLib.Variant | None) -> None:
@@ -605,13 +642,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
     ) -> None:
         open_window("AccountWizard")
 
-    @staticmethod
-    def _on_manage_roster_action(
-        _action: Gio.SimpleAction, param: GLib.Variant
-    ) -> None:
-        account = param.get_string()
-        open_window("ManageRoster", account=account)
-
     @structs.actionmethod
     def _on_block_contact(
         self, _action: Gio.SimpleAction, params: structs.AccountJidParam
@@ -660,26 +690,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
         account = param.get_string()
         open_window("PEPConfig", account=account)
 
-    @staticmethod
-    def _on_archive_action(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        account = param.get_string()
-        open_window("MamPreferences", account=account)
-
-    @staticmethod
-    def _on_blocking_action(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        account = param.get_string()
-        open_window("BlockingList", account=account)
-
-    @staticmethod
-    def _on_sync_history_action(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        account = param.get_string()
-        open_window("HistorySyncAssistant", account=account)
-
-    @staticmethod
-    def _on_server_info_action(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        account = param.get_string()
-        open_window("ServerInfo", account=account)
-
     @staticmethod
     def _on_xml_console_action(
         _action: Gio.SimpleAction, _param: GLib.Variant | None
@@ -722,7 +732,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _on_shortcuts_action(
         _action: Gio.SimpleAction, _param: GLib.Variant | None
     ) -> None:
-        ShortcutsWindow()
+        open_window("Preferences").show_page("shortcuts")
 
     @staticmethod
     def _on_features_action(
@@ -734,7 +744,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _on_about_action(
         _action: Gio.SimpleAction, _param: GLib.Variant | None
     ) -> None:
-        AboutDialog()
+        app.window.about_dialog.present()
 
     # @staticmethod
     # TODO Jingle FT
@@ -820,24 +830,22 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _on_remove_history_action(
         _action: Gio.SimpleAction, params: structs.AccountJidParam
     ) -> None:
-        def _remove() -> None:
+        def _on_response() -> None:
             app.storage.archive.remove_history_for_jid(params.account, params.jid)
 
             app.window.clear_chat_list_row(params.account, params.jid)
             control = app.window.get_control()
-            if not control.is_loaded(params.account, params.jid):
+            if not control.is_chat_active(params.account, params.jid):
                 return
 
             control.reset_view()
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Remove Chat History?"),
             _("Do you want to remove all chat history for this chat?"),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", callback=_remove),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Remove"),
+            appearance="destructive",
+            callback=_on_response,
         )
 
     @staticmethod
@@ -846,10 +854,10 @@ class GajimApplication(Gtk.Application, CoreApplication):
         _action: Gio.SimpleAction, params: structs.AccountJidParam
     ) -> None:
 
-        def _forget():
+        def _on_response() -> None:
             window = get_app_window("StartChatDialog")
             if window is not None:
-                window.remove_row(params.account, str(params.jid))
+                window.remove_row(params.account, params.jid)
 
             client = app.get_client(params.account)
             client.get_module("MUC").leave(params.jid)
@@ -857,12 +865,10 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
             app.storage.archive.remove_history_for_jid(params.account, params.jid)
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Forget this Group Chat?"),
             _("Do you want to remove this chat including its chat history?"),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", callback=_forget),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Remove"),
+            appearance="destructive",
+            callback=_on_response,
         )
