@@ -97,40 +97,6 @@ def make_menu_item(
     return item
 
 
-def get_main_menu() -> GajimMenu:
-    main_menu = GajimMenu()
-
-    gajim_menu_items: MenuItemListT = [
-        (_("_Start / Join Chat…"), "app.start-chat", GLib.Variant("as", ["", ""])),
-        (_("Create _Group Chat…"), "app.create-groupchat", GLib.Variant("s", "")),
-        (_("Pl_ugins"), "app.plugins", None),
-        (_("_Preferences"), "app.preferences", None),
-        (_("_Quit"), "app.quit", None),
-    ]
-    main_menu.append_submenu("_Gajim", GajimMenu.from_list(gajim_menu_items))
-
-    main_menu.add_submenu(_("_Accounts"))
-
-    view_menu_items: MenuItemListT = [
-        (_("_Debug Console"), "app.xml-console", None),
-        (_("_Toggle Menu Bar"), "win.toggle-menu-bar", None),
-    ]
-    main_menu.append_submenu(_("_View"), GajimMenu.from_list(view_menu_items))
-
-    help_menu_items: MenuItemListT = [
-        (_("_Wiki (Online)"), "app.content", None),
-        (_("FA_Q (Online)"), "app.faq", None),
-        (_("_Privacy Policy (Online)"), "app.privacy-policy", None),
-        (_("Join Support Chat"), "app.join-support-chat", None),
-        (_("_Keyboard Shortcuts"), "app.shortcuts", None),
-        (_("_Features"), "app.features", None),
-        (_("_About"), "app.about", None),
-    ]
-    main_menu.append_submenu(_("_Help"), GajimMenu.from_list(help_menu_items))
-
-    return main_menu
-
-
 def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
     account = contact.account
     jid = contact.jid
@@ -260,58 +226,10 @@ def get_account_menu(account: str) -> GajimMenu:
         (_("Profile"), f"app.{account}-profile", account),
         (_("Discover Services…"), f"app.{account}-services", account),
         (_("Execute Command…"), f"app.{account}-execute-command", params),
-        (_("Server Info"), f"app.{account}-server-info", account),
-    ]
-
-    menu = GajimMenu.from_list(menuitems)
-
-    advanced_menuitems: MenuItemListT = [
-        (_("Manage Contact List"), f"app.{account}-manage-roster", account),
-        (_("Archiving Preferences"), f"app.{account}-archive", account),
-        (_("Blocking List"), f"app.{account}-blocking", account),
         (_("PEP Configuration"), f"app.{account}-pep-config", account),
-        (_("Synchronize History…"), f"app.{account}-sync-history", account),
     ]
 
-    menu.append_submenu(_("Advanced"), GajimMenu.from_list(advanced_menuitems))
-
-    return menu
-
-
-def build_accounts_menu() -> None:
-    menubar = app.app.get_menubar()
-    assert isinstance(menubar, Gio.Menu)
-    # Accounts Submenu
-    menu_position = 1
-
-    acc_menu = menubar.get_item_link(menu_position, "submenu")
-    assert isinstance(acc_menu, Gio.Menu)
-    acc_menu.remove_all()
-
-    accounts_list = sorted(app.settings.get_active_accounts())
-    if not accounts_list:
-        add_account_item = Gio.MenuItem.new(_("_Add Account…"), "app.accounts::")
-        acc_menu.append_item(add_account_item)
-        return
-
-    if len(accounts_list) > 1:
-        manage_accounts_item = Gio.MenuItem.new(
-            _("_Manage Accounts…"), "app.accounts::"
-        )
-        acc_menu.append_item(manage_accounts_item)
-        add_contact_item = Gio.MenuItem.new(_("Add _Contact…"), "app.add-contact::")
-        acc_menu.append_item(add_contact_item)
-        for acc in accounts_list:
-            label = escape_mnemonic(app.get_account_label(acc))
-            acc_menu.append_submenu(label, get_account_menu(acc))
-    else:
-        acc_menu = get_account_menu(accounts_list[0])
-        manage_account_item = Gio.MenuItem.new(_("_Manage Account…"), "app.accounts::")
-        acc_menu.insert_item(0, manage_account_item)
-        add_contact_item = Gio.MenuItem.new(_("Add _Contact…"), "app.add-contact::")
-        acc_menu.insert_item(1, add_contact_item)
-        menubar.remove(menu_position)
-        menubar.insert_submenu(menu_position, _("_Accounts"), acc_menu)
+    return GajimMenu.from_list(menuitems)
 
 
 def get_encryption_menu() -> GajimMenu:
@@ -532,7 +450,7 @@ def get_start_chat_row_menu(account: str, jid: JID | None) -> GajimMenu | None:
     if isinstance(contact, GroupchatContact):
         account_jid_params = AccountJidParam(account=account, jid=jid)
         menuitems.append(
-            (_("Forget this Group Chat"), "app.forget-groupchat", account_jid_params)
+            (_("Forget this Group Chat…"), "app.forget-groupchat", account_jid_params)
         )
 
     return GajimMenu.from_list(menuitems)
@@ -698,8 +616,11 @@ def get_groupchat_participant_menu(
     disco = group_chat.get_disco()
     assert disco is not None
     muc_prefer_direct_msg = app.settings.get("muc_prefer_direct_msg")
-    if disco.muc_is_nonanonymous and muc_prefer_direct_msg:
-        assert contact.real_jid is not None
+    if (
+        disco.muc_is_nonanonymous
+        and muc_prefer_direct_msg
+        and contact.real_jid is not None
+    ):
         dm_params = AddChatActionParams(
             account=account, jid=contact.real_jid, type="chat", select=True
         )
@@ -949,40 +870,52 @@ def get_workspace_menu(workspace_id: str) -> GajimMenu:
     return GajimMenu.from_list(menuitems)
 
 
-def get_manage_roster_menu(groups: list[str], single_selection: bool) -> GajimMenu:
+def get_manage_roster_menu(
+    account: str, groups: list[str], single_selection: bool
+) -> GajimMenu:
     menu = GajimMenu()
 
-    menuitems: MenuItemListT = [(_("New Group…"), "win.move-to-new-group", None)]
+    menuitems: MenuItemListT = [
+        (_("New Group…"), f"win.{account}-move-to-new-group", None)
+    ]
 
     for group in groups:
-        menuitems.append((group, "win.move-to-group", group))
+        menuitems.append((group, f"win.{account}-move-to-group", group))
 
     menu.append_submenu(_("Move to Group"), GajimMenu.from_list(menuitems))
 
-    menuitems: MenuItemListT = [(_("New Group…"), "win.add-to-new-group", None)]
+    menuitems: MenuItemListT = [
+        (_("New Group…"), f"win.{account}-add-to-new-group", None)
+    ]
 
     for group in groups:
-        menuitems.append((group, "win.add-to-group", group))
+        menuitems.append((group, f"win.{account}-add-to-group", group))
 
     menu.append_submenu(_("Add to Group"), GajimMenu.from_list(menuitems))
 
-    menu.add_item(_("Remove from Group"), "win.remove-from-group", None)
+    menu.add_item(_("Remove from Group"), f"win.{account}-remove-from-group", None)
     if single_selection:
-        menu.add_item(_("Rename…"), "win.change-name", None)
+        menu.add_item(_("Rename…"), f"win.{account}-change-name", None)
 
-    menu.add_item(_("Remove from Contact List…"), "win.remove-from-roster", None)
+    menu.add_item(
+        _("Remove from Contact List…"), f"win.{account}-remove-from-roster", None
+    )
 
     return menu
 
 
-def get_manage_roster_import_menu(accounts: list[tuple[str, str]]) -> GajimMenu:
+def get_manage_roster_import_menu(
+    account: str, accounts: list[tuple[str, str]]
+) -> GajimMenu:
     menu = GajimMenu()
-    menu.add_item(_("Import from File"), "win.import-from-file", None)
+    menu.add_item(_("Import from File"), f"win.{account}-import-from-file", None)
 
     if accounts:
         menuitems: MenuItemListT = []
-        for account, label in accounts:
-            menuitems.append((label, "win.import-from-account", account))
+        for remote_account, label in accounts:
+            menuitems.append(
+                (label, f"win.{account}-import-from-account", remote_account)
+            )
 
         menu.append_submenu(_("Import from Account"), GajimMenu.from_list(menuitems))
     else:
