@@ -13,6 +13,7 @@ from collections.abc import Iterator
 from dataclasses import dataclass
 from enum import Enum
 
+from gi.repository import Adw
 from gi.repository import Gdk
 from gi.repository import GLib
 from gi.repository import GObject
@@ -49,6 +50,8 @@ class PlaceholderMode(Enum):
 
 
 class SearchView(Gtk.Box, SignalManager, EventHelper):
+    __gtype_name__ = "SearchView"
+
     __gsignals__ = {
         "hide-search": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
@@ -146,7 +149,7 @@ class SearchView(Gtk.Box, SignalManager, EventHelper):
 
         self._ui.results_listbox.remove_all()
         # Set placeholder again, otherwise it won't be shown
-        self._ui.results_listbox.set_placeholder(self._ui.placeholder)
+        self._ui.results_listbox.set_placeholder(self._ui.status_page)
 
         self._ui.results_listbox.set_header_func(self._header_func)
         self._ui.results_scrolled.get_vadjustment().set_value(0)
@@ -205,23 +208,25 @@ class SearchView(Gtk.Box, SignalManager, EventHelper):
         self._add_results()
 
     def _set_placeholder_mode(self, placeholder_mode: PlaceholderMode) -> None:
-        self._ui.placeholder_image.remove_css_class("spin")
-
         if placeholder_mode == PlaceholderMode.SEARCHING:
-            self._ui.placeholder_image.add_css_class("spin")
-            icon_name = "view-refresh-symbolic"
-            text = _("Searching…")
+            self._ui.status_page.set_title(_("Searching…"))
+            self._ui.status_page.set_description(None)
+            self._ui.status_page.set_paintable(
+                Adw.SpinnerPaintable(widget=self._ui.status_page)
+            )
+            return
 
-        elif placeholder_mode == PlaceholderMode.NO_RESULTS:
-            icon_name = "action-unavailable-symbolic"
-            text = _("No results")
+        if placeholder_mode == PlaceholderMode.NO_RESULTS:
+            text = _("No Results Found")
+            description = _("Try a different search")
         else:
             # PlaceholderMode.INITIAL
-            icon_name = "system-search-symbolic"
-            text = _("Search your conversation")
+            text = _("Search")
+            description = _("Search in chats…")
 
-        self._ui.placeholder_image.set_from_icon_name(icon_name)
-        self._ui.placeholder_label.set_text(text)
+        self._ui.status_page.set_icon_name("lucide-search-symbolic")
+        self._ui.status_page.set_title(text)
+        self._ui.status_page.set_description(description)
 
     def _add_results(self) -> None:
         assert self._results_iterator is not None
@@ -320,7 +325,7 @@ class SearchView(Gtk.Box, SignalManager, EventHelper):
     def _on_date_selected(self, calendar: Gtk.Calendar) -> None:
         date_time = calendar.get_date()
         date = dt.datetime(*date_time.get_ymd())
-        self._scroll_to_date(date)
+        app.window.get_control().scroll_to_date(date)
 
     def _on_first_date_selected(self, _button: Gtk.Button) -> None:
         assert self._first_date is not None
@@ -368,42 +373,20 @@ class SearchView(Gtk.Box, SignalManager, EventHelper):
 
         self._ui.calendar.select_day(convert_py_to_glib_datetime(date))
 
-    def _scroll_to_date(self, date: dt.datetime) -> None:
-        control = app.window.get_control()
-        if not control.has_active_chat():
-            return
-        if control.contact.jid == self._jid:
-
-            assert self._jid is not None
-            assert self._account is not None
-
-            meta = app.storage.archive.get_first_message_meta_for_date(
-                self._account, self._jid, date
-            )
-            if meta is None:
-                return
-
-            control.scroll_to_message(*meta)
-
     @staticmethod
     def _on_row_activated(_listbox: SearchView, row: ResultRow) -> None:
         control = app.window.get_control()
-        if control.has_active_chat():
-            if control.contact.jid == row.remote_jid:
-                control.scroll_to_message(row.pk, row.timestamp)
-                return
+        if not control.is_chat_active(row.account, row.remote_jid):
 
-        # Other chat or no control opened
-        jid = row.remote_jid
-        chat_type = "chat"
-        if row.type == MessageType.GROUPCHAT:
-            chat_type = "groupchat"
-        elif row.type == MessageType.PM:
-            chat_type = "pm"
-        app.window.add_chat(row.account, jid, chat_type, select=True)
-        control = app.window.get_control()
-        if control.has_active_chat():
-            control.scroll_to_message(row.pk, row.timestamp)
+            chat_type = "chat"
+            if row.type == MessageType.GROUPCHAT:
+                chat_type = "groupchat"
+            elif row.type == MessageType.PM:
+                chat_type = "pm"
+
+            app.window.add_chat(row.account, row.remote_jid, chat_type, select=True)
+
+        control.scroll_to_message(row.pk, row.timestamp)
 
     def set_focus(self) -> None:
         self._ui.search_entry.grab_focus()
